﻿using System;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace Chart_GettingStarted
{
	public partial class ViewController : UIViewController
	{
		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}

		SFChart chart;
		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			chart = new SFChart();
			chart.Frame = this.View.Frame;

			//Define the title for the Chart.
			chart.Title.Text = new NSString("Weather Analysis");

			//Adding Primary Axis for the Chart.
			SFCategoryAxis primaryAxis = new SFCategoryAxis();
			primaryAxis.Title.Text = new NSString("Month");

			chart.PrimaryAxis = primaryAxis;

			//Adding Secondary Axis for the Chart.
			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			secondaryAxis.Title.Text = new NSString("Temperature");

			chart.SecondaryAxis = secondaryAxis;

			//Defining the data source for the Chart.
			ChartDataModel dataModel = new ChartDataModel();
			chart.DataSource = dataModel as SFChartDataSource;

			//Adding our Chart as a sub view.
			this.View.AddSubview(chart);
		}

		public override void ViewDidLayoutSubviews()
		{
			chart.Frame = this.View.Frame;
			base.ViewDidLayoutSubviews();
		}

	}

	public class ChartDataModel : SFChartDataSource
	{
		NSMutableArray highTemperature;

		NSMutableArray lowTemperature;

		public ChartDataModel()
		{
			highTemperature = new NSMutableArray();
			lowTemperature = new NSMutableArray();

			AddDataPointsForChart("Jan", 44, 30);
			AddDataPointsForChart("Feb", 55, 28);
			AddDataPointsForChart("Mar", 62, 27);

		}

		void AddDataPointsForChart(String month, Double high, Double low)
		{
			highTemperature.Add(new SFChartDataPoint(NSObject.FromObject(month), NSObject.FromObject(high)));

			lowTemperature.Add(new SFChartDataPoint(NSObject.FromObject(month), NSObject.FromObject(low)));

		}

		[Export("numberOfSeriesInChart:")]
		public override nint NumberOfSeriesInChart(SFChart chart)
		{
			return 2;
			//returns no of series required for the chart.
		}

		[Export("chart:seriesAtIndex:")]
		public override SFSeries GetSeries(SFChart chart, nint index)
		{
			//returns the series for the chart.
			if (index == 0)
			{
				SFStackingBar100Series series1 = new SFStackingBar100Series();
				series1.BorderWidth = 1;
				series1.EnableTooltip = true;
				series1.BorderColor = UIColor.White;
				series1.ColorModel.Palette = SFChartColorPalette.Custom;
				series1.ColorModel.CustomColors = NSArray.FromObjects(UIColor.Blue, UIColor.Green, UIColor.Orange);
				return series1;
			}
			else
			{
				SFStackingBar100Series series2 = new SFStackingBar100Series();
				series2.BorderWidth = 1;
				series2.EnableTooltip = true;
				series2.BorderColor = UIColor.White;
				series2.EnableTooltip = true;
				series2.ColorModel.Palette = SFChartColorPalette.Custom;
				series2.ColorModel.CustomColors = NSArray.FromObjects(UIColor.Blue, UIColor.Green, UIColor.Orange);
				return series2;
			}
		}

		[Export("chart:dataPointAtIndex:forSeriesAtIndex:")]
		public override SFChartDataPoint GetDataPoint(SFChart chart, nint index, nint seriesIndex)
		{
			//returns the datapoint for each series.
			if (seriesIndex == 0)
			{
				return highTemperature.GetItem<SFChartDataPoint>((nuint)index);
			}
			else
			{
				return lowTemperature.GetItem<SFChartDataPoint>((nuint)index);
			}
		}

		[Export("chart:numberOfDataPointsForSeriesAtIndex:")]
		public override nint GetNumberOfDataPoints(SFChart chart, nint index)
		{

			return (System.nint)highTemperature.Count;
			//No of datapoints needed for each series.
		}
	}
}

